/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.list.type.internal.security.permission.resource;

import com.liferay.list.type.constants.ListTypeConstants;
import com.liferay.list.type.model.ListTypeDefinition;
import com.liferay.list.type.service.ListTypeDefinitionLocalService;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.security.auth.PrincipalException;
import com.liferay.portal.kernel.security.permission.PermissionChecker;
import com.liferay.portal.kernel.security.permission.resource.ModelResourcePermission;
import com.liferay.portal.kernel.security.permission.resource.PortletResourcePermission;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Gabriel Albuquerque
 */
@Component(
	property = "model.class.name=com.liferay.list.type.model.ListTypeDefinition",
	service = ModelResourcePermission.class
)
public class ListTypeDefinitionModelResourcePermission
	implements ModelResourcePermission<ListTypeDefinition> {

	@Override
	public void check(
			PermissionChecker permissionChecker,
			ListTypeDefinition listTypeDefinition, String actionId)
		throws PortalException {

		if (!contains(permissionChecker, listTypeDefinition, actionId)) {
			throw new PrincipalException.MustHavePermission(
				permissionChecker, ListTypeDefinition.class.getName(),
				listTypeDefinition.getPrimaryKey(), actionId);
		}
	}

	@Override
	public void check(
			PermissionChecker permissionChecker, long listTypeDefinitionId,
			String actionId)
		throws PortalException {

		if (!contains(permissionChecker, listTypeDefinitionId, actionId)) {
			throw new PrincipalException.MustHavePermission(
				permissionChecker, ListTypeDefinition.class.getName(),
				listTypeDefinitionId, actionId);
		}
	}

	@Override
	public boolean contains(
			PermissionChecker permissionChecker,
			ListTypeDefinition listTypeDefinition, String actionId)
		throws PortalException {

		if (permissionChecker.hasOwnerPermission(
				permissionChecker.getCompanyId(),
				ListTypeDefinition.class.getName(),
				listTypeDefinition.getListTypeDefinitionId(),
				listTypeDefinition.getUserId(), actionId) ||
			permissionChecker.hasPermission(
				null, ListTypeDefinition.class.getName(),
				listTypeDefinition.getPrimaryKey(), actionId)) {

			return true;
		}

		return false;
	}

	@Override
	public boolean contains(
			PermissionChecker permissionChecker, long listTypeDefinitionId,
			String actionId)
		throws PortalException {

		return contains(
			permissionChecker,
			_listTypeDefinitionLocalService.getListTypeDefinition(
				listTypeDefinitionId),
			actionId);
	}

	@Override
	public String getModelName() {
		return ListTypeDefinition.class.getName();
	}

	@Override
	public PortletResourcePermission getPortletResourcePermission() {
		return _portletResourcePermission;
	}

	@Reference
	private ListTypeDefinitionLocalService _listTypeDefinitionLocalService;

	@Reference(
		target = "(resource.name=" + ListTypeConstants.RESOURCE_NAME + ")"
	)
	private PortletResourcePermission _portletResourcePermission;

}