/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.list.type.service.impl;

import com.liferay.list.type.model.ListTypeDefinition;
import com.liferay.list.type.model.ListTypeEntry;
import com.liferay.list.type.service.base.ListTypeEntryServiceBaseImpl;
import com.liferay.list.type.service.persistence.ListTypeDefinitionPersistence;
import com.liferay.portal.aop.AopService;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.security.permission.ActionKeys;
import com.liferay.portal.kernel.security.permission.resource.ModelResourcePermission;

import java.util.List;
import java.util.Locale;
import java.util.Map;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Gabriel Albuquerque
 */
@Component(
	property = {
		"json.web.service.context.name=listtype",
		"json.web.service.context.path=ListTypeEntry"
	},
	service = AopService.class
)
public class ListTypeEntryServiceImpl extends ListTypeEntryServiceBaseImpl {

	@Override
	public ListTypeEntry addListTypeEntry(
			String externalReferenceCode, long listTypeDefinitionId, String key,
			Map<Locale, String> nameMap)
		throws PortalException {

		ListTypeDefinition listTypeDefinition =
			_listTypeDefinitionPersistence.findByPrimaryKey(
				listTypeDefinitionId);

		_listTypeDefinitionModelResourcePermission.check(
			getPermissionChecker(),
			listTypeDefinition.getListTypeDefinitionId(), ActionKeys.UPDATE);

		return listTypeEntryLocalService.addListTypeEntry(
			externalReferenceCode, getUserId(), listTypeDefinitionId, key,
			nameMap);
	}

	@Override
	public ListTypeEntry deleteListTypeEntry(long listTypeEntryId)
		throws PortalException {

		ListTypeEntry listTypeEntry = listTypeEntryPersistence.findByPrimaryKey(
			listTypeEntryId);

		_listTypeDefinitionModelResourcePermission.check(
			getPermissionChecker(), listTypeEntry.getListTypeDefinitionId(),
			ActionKeys.UPDATE);

		return listTypeEntryLocalService.deleteListTypeEntry(listTypeEntryId);
	}

	@Override
	public List<ListTypeEntry> getListTypeEntries(
			long listTypeDefinitionId, int start, int end)
		throws PortalException {

		_listTypeDefinitionModelResourcePermission.check(
			getPermissionChecker(), listTypeDefinitionId, ActionKeys.VIEW);

		return listTypeEntryLocalService.getListTypeEntries(
			listTypeDefinitionId, start, end);
	}

	@Override
	public int getListTypeEntriesCount(long listTypeDefinitionId)
		throws PortalException {

		_listTypeDefinitionModelResourcePermission.check(
			getPermissionChecker(), listTypeDefinitionId, ActionKeys.VIEW);

		return listTypeEntryLocalService.getListTypeEntriesCount(
			listTypeDefinitionId);
	}

	@Override
	public ListTypeEntry getListTypeEntry(long listTypeEntryId)
		throws PortalException {

		ListTypeEntry listTypeEntry = listTypeEntryPersistence.findByPrimaryKey(
			listTypeEntryId);

		_listTypeDefinitionModelResourcePermission.check(
			getPermissionChecker(), listTypeEntry.getListTypeDefinitionId(),
			ActionKeys.VIEW);

		return listTypeEntryLocalService.getListTypeEntry(listTypeEntryId);
	}

	@Override
	public ListTypeEntry getListTypeEntryByExternalReferenceCode(
			String externalReferenceCode, long companyId)
		throws PortalException {

		ListTypeEntry listTypeEntry =
			listTypeEntryLocalService.getListTypeEntryByExternalReferenceCode(
				externalReferenceCode, companyId);

		_listTypeDefinitionModelResourcePermission.check(
			getPermissionChecker(), listTypeEntry.getListTypeDefinitionId(),
			ActionKeys.VIEW);

		return listTypeEntry;
	}

	@Override
	public ListTypeEntry updateListTypeEntry(
			String externalReferenceCode, long listTypeEntryId,
			Map<Locale, String> nameMap)
		throws PortalException {

		ListTypeEntry listTypeEntry = listTypeEntryPersistence.findByPrimaryKey(
			listTypeEntryId);

		_listTypeDefinitionModelResourcePermission.check(
			getPermissionChecker(), listTypeEntry.getListTypeDefinitionId(),
			ActionKeys.UPDATE);

		return listTypeEntryLocalService.updateListTypeEntry(
			externalReferenceCode, listTypeEntryId, nameMap);
	}

	@Reference(
		target = "(model.class.name=com.liferay.list.type.model.ListTypeDefinition)"
	)
	private ModelResourcePermission<ListTypeDefinition>
		_listTypeDefinitionModelResourcePermission;

	@Reference
	private ListTypeDefinitionPersistence _listTypeDefinitionPersistence;

}